@@ -196,6 +196,8 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1,  tree = False):
     # do = 999999
 
 
+    print( general.freemem() )
+
     #*************
     start = general.filename_decomp(filename)   #  - get start
 
@@ -222,9 +224,19 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1,  tree = False):
 
     #*************
     df = general.pd_read_table(filename, sort = True)
-    print(df.dtypes)
-    print("D... channels present:",df['ch'].unique() )
+    #print(df.dtypes)
     print(df)
+    chan_available = df['ch'].unique()
+    print("D... channels present:", chan_available)
+    if chan in chan_available:
+        print(f"X... no events in channel {chan}")
+        return
+    print("D... x        present:",df['x'].unique() )
+    if 'y' in df:
+        print("D... y        present:",df['y'].unique() )
+    print("D... Emin            :",df['E'].min() )
+    print("D... Emax            :",df['E'].max() )
+
 
 
     if (od!=0) and (do<9999999):
@@ -245,6 +257,9 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1,  tree = False):
         df1 = df
 
 
+    #*************  dt us    and next_E
+    df = general.pd_link_next(df)
+
     #*************   one channel; time span
     len_dfzero,_ = general.pd_detect_zeroes(df1, chan) # df1[ (df1.E==0) ]
 
@@ -313,11 +328,15 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1,  tree = False):
     print(f"D... {outfile2} is save as a duplicate")
     copyfile(outfile, outfile2)
 
+    print( general.freemem() )
 
 
     if tree:
         #*************
         general.save_to_tree(df2, filename) #
+
+    print( general.freemem() )
+
     return
 
 
